@@ -10,8 +10,8 @@ class RichTextField(models.TextField):
     """
     Field that construct the textarea field with CKEditor widget.
     """
-    def __init__(self,config_name='COMPLETE_CONFIG',*args, **kwargs):
-        self.config_name = config_name
+    def __init__(self,*args, **kwargs):
+        self.config_name = kwargs.pop("config_name", "COMPLETE_CONFIG")
         super(RichTextField, self).__init__(*args, **kwargs)
     
     def formfield(self, **kwargs):
